@@ -19,6 +19,10 @@
  * 02111-1307, USA.
  */
 
+/*!
+ * \todo build fails when abiword built without printing support.
+ */
+
 #ifdef ABI_PLUGIN_BUILTIN
 #define abi_plugin_register abipgn_abicommand_register
 #define abi_plugin_unregister abipgn_abicommand_unregister
@@ -34,6 +38,7 @@
 #include <errno.h>
 
 #include <glib.h>
+#include <libgnomeprint/gnome-print-job.h>
 
 #include "xap_Module.h"
 #include "xap_App.h"
