@@ -276,17 +276,21 @@ abi_control_gui_init (GObject *object)
 	control->object_id = NULL;
 }
 
+static GObjectClass *parent_klass;
+
 static void
 abi_control_gui_finalize (GObject *object)
 {
 	AbiControlGUI *control = ABI_CONTROL_GUI (object);
 	if (control->object_id)
 		g_free (control->object_id);
+	(parent_klass->finalize) (object);
 }
 
 static void
 abi_control_gui_class_init (GObjectClass *klass)
 {
+	parent_klass = static_cast<GObjectClass*>(g_type_class_peek_parent (klass));
 	klass->finalize = abi_control_gui_finalize;
 }
 
