@@ -351,7 +351,7 @@ static bool s_AskForMathMLPathname(XAP_Frame * pFrame,
 	// raise the file-open dialog for inserting a MathML equation.
 	// return a_OK or a_CANCEL depending on which button
 	// the user hits.
-	// return a pointer a UT_strdup()'d string containing the
+	// return a pointer a g_strdup()'d string containing the
 	// pathname the user entered -- ownership of this goes
 	// to the caller (so free it when you're done with it).
 
@@ -388,7 +388,7 @@ static bool s_AskForMathMLPathname(XAP_Frame * pFrame,
 		const char * szResultPathname = pDialog->getPathname();
 		UT_DEBUGMSG(("MATHML Path Name selected = %s \n",szResultPathname));
 		if (szResultPathname && *szResultPathname)
-			UT_cloneString(*ppPathname,szResultPathname);
+			*ppPathname = g_strdup(szResultPathname);
 
 		UT_sint32 type = pDialog->getFileType();
 
@@ -460,7 +460,7 @@ AbiMathView_FileInsert(AV_View* v, EV_EditMethodCallData *d)
 
 	/* Create the data item */
 	const char* mimetypeMATHML = NULL;
-	mimetypeMATHML = UT_strdup("application/mathml+xml");
+	mimetypeMATHML = g_strdup("application/mathml+xml");
 	UT_uint32 uid = pDoc->getUID(UT_UniqueId::Image);
 	UT_UTF8String sUID;
 	UT_UTF8String_sprintf(sUID,"%d",uid);
@@ -757,7 +757,7 @@ bool GR_MathManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
 	UT_UTF8String sID = "snapshot-png-";
 	sID += szDataID;
 
-	mimetypePNG = UT_strdup("image/png");
+	mimetypePNG = g_strdup("image/png");
 	UT_DEBUGMSG(("Making data-item of name %s \n",sID.utf8_str()));
 	pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
 
