@@ -163,7 +163,7 @@ void ODe_Frame_Listener::_openODTextbox(const PP_AttrProp& rAP,
     ok = rAP.getProperty("position-to", pValue);
     UT_ASSERT (ok && pValue != NULL);
 
-    if (!strcmp(pValue, "block-above-text")) {
+    if (pValue && !strcmp(pValue, "block-above-text")) {
 
         ODe_writeAttribute(output, "text:anchor-type", "paragraph");
 
