@@ -85,7 +85,7 @@ bool ODe_Style_Style::write(GsfOutput* pODT, const UT_UTF8String& rSpacesOffset)
     output += "<style:style";
     
     if (m_name.empty()) {
-        UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+        UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
         return false;
     }
     escape = m_name;
@@ -94,7 +94,7 @@ bool ODe_Style_Style::write(GsfOutput* pODT, const UT_UTF8String& rSpacesOffset)
     output += "\"";
     
     if (m_family.empty()) {
-        UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+        UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
         return false;
     }
     output += " style:family=\"";
@@ -196,6 +196,11 @@ bool ODe_Style_Style::hasTextStyleProps(const PP_AttrProp* pAP) {
     if (ok && pValue != NULL) {
         return true;
     }
+
+    ok = pAP->getProperty("display", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
     
     return false;
 }
@@ -867,13 +872,14 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("bgcolor", pValue);
     if (ok && pValue != NULL) {
-        
-        if (strlen(pValue)==6) {
+        int len = strlen(pValue);
+        if (len==6) {
             // It should be a RGB color.
             UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
-        } else {
-            UT_ASSERT(strcmp("transparent", pValue)==0);
+        } else if((len==7) || (strcmp("transparent", pValue)==0)) {
             m_backgroundColor = pValue;
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
         }
     }
     
@@ -1063,7 +1069,9 @@ bool ODe_Style_Style::TextProps::isEmpty() const {
            m_language.empty() &&
            m_country.empty() &&
            m_fontStyle.empty() &&
-           m_fontWeight.empty();
+           m_fontWeight.empty() &&
+           m_backgroundColor.empty() &&
+           m_display.empty();
 }
 
 
@@ -1077,12 +1085,13 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("color", pValue);
     if (ok && pValue != NULL) {
-        if (strlen(pValue)==6) {
+        int len = strlen(pValue);
+        if (len == 6) {
             UT_UTF8String_sprintf(m_color, "#%s", pValue);
-        } else {
-            UT_ASSERT(strlen(pValue)==7);
-            UT_ASSERT(pValue[0]=='#');
+        } else if ((len == 7) && (pValue[0] == '#')){
             m_color = pValue;
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
         }
     }
     
@@ -1161,25 +1170,35 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
             m_language = "none";
             m_country = "none";
         } else {
-            gchar strLanguage[3];
+            gchar strLanguage[4];
             gchar strCountry[3];
 
-            // All valid strings should have 5 chars. e.g.: "en-US"
-            UT_ASSERT( strlen(pValue) == 5); 
-            
-            if (strlen(pValue) == 5) {
+            int len = strlen(pValue);
+            bool bLong = (len == 6);
+            // Note: not all language codes are 5 characters (e.g. cop-EG)
+            if ((len == 5) || bLong) {
                 strLanguage[0] = pValue[0];
                 strLanguage[1] = pValue[1];
-                strLanguage[2] = 0;
+
+                if(bLong) {
+                    strLanguage[2] = pValue[2];
+                    // pValue[3] == '-'
+                    strCountry[0] = pValue[4];
+                    strCountry[1] = pValue[5];
+                } else {
+                    strLanguage[2] = 0;
+                    // pValue[2] == '-'
+                    strCountry[0] = pValue[3];
+                    strCountry[1] = pValue[4];
+                }
                 
-                // pValue[2] == '-'
-                
-                strCountry[0] = pValue[3];
-                strCountry[1] = pValue[4];
+                strLanguage[3] = 0;
                 strCountry[2] = 0;
                
                 m_language = strLanguage;
                 m_country = strCountry;
+            } else {
+                UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             }
         }
     }
@@ -1201,6 +1220,30 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
             m_fontWeight = "normal";
         }
     }
+
+
+    ok = rAP.getProperty("bgcolor", pValue);
+    if (ok && pValue != NULL) {
+        int len = strlen(pValue);
+        if (len==6) {
+            // It should be an RGB color.
+            UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        } else if ((len == 7) || (strcmp("transparent", pValue) == 0)) {
+            m_backgroundColor = pValue;
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
+    }
+
+
+    ok = rAP.getProperty("display", pValue);
+    if (ok && pValue != NULL) {
+        if (!strcmp(pValue, "none")) {
+            m_display = "none";
+        } else {
+            m_display = "true";
+        }
+    }
 }
 
 
@@ -1227,6 +1270,8 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     ODe_writeAttribute(rOutput, "fo:country", m_country);
     ODe_writeAttribute(rOutput, "fo:font-style", m_fontStyle);
     ODe_writeAttribute(rOutput, "fo:font-weight", m_fontWeight);
+    ODe_writeAttribute(rOutput, "fo:background-color", m_backgroundColor);
+    ODe_writeAttribute(rOutput, "text:display", m_display);
     
     rOutput += "/>\n";
 }
@@ -1248,6 +1293,8 @@ ODe_Style_Style::TextProps& ODe_Style_Style::TextProps::operator=(
     m_country = rTextProps.m_country;
     m_fontStyle = rTextProps.m_fontStyle;
     m_fontWeight = rTextProps.m_fontWeight;
+    m_backgroundColor = rTextProps.m_backgroundColor;
+    m_display = rTextProps.m_display;
     
     return *this;
 }
@@ -1269,7 +1316,9 @@ bool ODe_Style_Style::TextProps::operator==(
         m_language        == rTextProps.m_language &&
         m_country         == rTextProps.m_country &&
         m_fontStyle       == rTextProps.m_fontStyle &&
-        m_fontWeight      == rTextProps.m_fontWeight;
+        m_fontWeight      == rTextProps.m_fontWeight &&
+        m_backgroundColor == rTextProps.m_backgroundColor &&
+        m_display         == rTextProps.m_display;
 }
 
 
@@ -1300,7 +1349,14 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("background-color", pValue);
     if (ok && pValue != NULL) {
-        UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        int len = strlen(pValue);
+        if(len == 6) {
+            UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        } else if (len == 7) {
+            m_backgroundColor = pValue;
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
     }
     
     ok = rAP.getProperty("table-column-props", pValue);
@@ -1602,7 +1658,14 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("background-color", pValue);
     if (ok && pValue != NULL) {
-        UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        int len = strlen(pValue);
+        if(len == 6) {
+            UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        } else if (len == 7) {
+            m_backgroundColor = pValue;
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
     }
 }
 
@@ -1795,7 +1858,14 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("background-color", pValue);
     if (ok && pValue != NULL) {
-        UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        int len = strlen(pValue);
+        if(len == 6) {
+            UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
+        } else if (len == 7) {
+            m_backgroundColor = pValue;
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
     }
     
     
