@@ -282,16 +282,12 @@ void ODe_Text_Listener::closeFrame(ODe_ListenerAction& rAction) {
 void ODe_Text_Listener::openField(const fd_Field* field, const UT_UTF8String& fieldType, const UT_UTF8String& fieldValue) {
     UT_return_if_fail(field && fieldType.length());
 
-    if(!fieldValue.length()) {
-       // for some reason, field values aren't calculated when files are converted on the command line;
-       // instead of returning and creating an invalid document, we'll just assert.
-       UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-    }
-
     UT_UTF8String escape = fieldValue;
     escape.escapeXML();
 
-    if(!strcmp(fieldType.utf8_str(),"page_number")) {
+    if(!strcmp(fieldType.utf8_str(),"list_label")) {
+        return;  // don't do anything with list labels
+    } else if(!strcmp(fieldType.utf8_str(),"page_number")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:page-number>%s",escape.utf8_str()));
     } else if(!strcmp(fieldType.utf8_str(),"page_count")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:page-count>%s",escape.utf8_str()));
@@ -329,7 +325,9 @@ void ODe_Text_Listener::openField(const fd_Field* field, const UT_UTF8String& fi
 void ODe_Text_Listener::closeField(const UT_UTF8String& fieldType) {
     UT_return_if_fail(fieldType.length());
 
-    if(!strcmp(fieldType.utf8_str(),"page_number")) {
+    if(!strcmp(fieldType.utf8_str(),"list_label")) {
+        return;  // don't do anything with list labels
+    } else if(!strcmp(fieldType.utf8_str(),"page_number")) {
         ODe_writeToFile(m_pParagraphContent, "</text:page-number>");
     } else if(!strcmp(fieldType.utf8_str(),"page_count")) {
         ODe_writeToFile(m_pParagraphContent, "</text:page-count>");
