@@ -57,15 +57,14 @@ bool ODi_Abi_Data::addImageDataItem(UT_String& rDataId, const gchar** ppAtts) {
     UT_return_val_if_fail(pHRef,false);
 
     // If we have a string smaller then this we are in trouble. File corrupted?
-    UT_return_val_if_fail((strlen(pHRef) >= strlen("Pictures/a")), false);
+    UT_return_val_if_fail((strlen(pHRef) >= 10 /*10 == strlen("Pictures/a")*/), false);
 
-    const UT_UTF8String* pID;
     UT_Error error = UT_OK;
     UT_ByteBuf img_buf;
     GsfInfile* pPictures_dir;
     char* pMimetype;
     FG_Graphic* pFG = NULL;
-    UT_ByteBuf* pPictData = NULL;
+    const UT_ByteBuf* pPictData = NULL;
     UT_uint32 imageID;
     
     // The subdirectory that holds the picture. e.g: "ObjectReplacements" or "Pictures"
@@ -74,12 +73,12 @@ bool ODi_Abi_Data::addImageDataItem(UT_String& rDataId, const gchar** ppAtts) {
     // The file name of the picture. e.g.: "Object 1" or "10000201000000D100000108FF0E3707.png" 
     UT_String fileName;
     
-    pID = m_href_to_id[pHRef];
-    if (pID != NULL) {
+    const std::string id = m_href_to_id[pHRef];
+    if (!id.empty()) {
         // This image was already added.
         // Use the existing data item id.
-        rDataId = pID->utf8_str();
-        return false;
+        rDataId = id;
+        return true;
     }
     
     
@@ -88,7 +87,10 @@ bool ODi_Abi_Data::addImageDataItem(UT_String& rDataId, const gchar** ppAtts) {
     UT_String_sprintf(rDataId, "%d", imageID);
     
     // Add this id to the list
-    UT_ASSERT(m_href_to_id.ins(pHRef, rDataId.c_str()) == TRUE);
+    UT_ASSERT(m_href_to_id.insert(m_href_to_id.begin(),
+								  href_id_map_t::value_type(pHRef, 
+															rDataId.c_str())
+				  ) != m_href_to_id.end());
 
     _splitDirectoryAndFileName(pHRef, dirName, fileName);
 
@@ -159,9 +161,8 @@ bool ODi_Abi_Data::addObjectDataItem(UT_String& rDataId, const gchar** ppAtts, i
     UT_return_val_if_fail(pHRef,false);
 
     // If we have a string smaller then this we are in trouble. File corrupted?
-    UT_return_val_if_fail((strlen(pHRef) >= strlen("Pictures/a")), false);
+    UT_return_val_if_fail((strlen(pHRef) >= 10 /*10 == strlen("Pictures/a")*/), false);
 
-    const UT_UTF8String* pID;
     UT_Error error = UT_OK;
     UT_ByteBuf *object_buf;
     GsfInfile* pObjects_dir;
@@ -174,12 +175,12 @@ bool ODi_Abi_Data::addObjectDataItem(UT_String& rDataId, const gchar** ppAtts, i
     // The file name of the picture. e.g.: "Object 1" or "10000201000000D100000108FF0E3707.png" 
     UT_String fileName;
     
-    pID = m_href_to_id[pHRef];
-    if (pID != NULL) {
+    const std::string id = m_href_to_id[pHRef];
+    if (!id.empty()) {
         // This object was already added.
         // Use the existing data item id.
-        rDataId = pID->utf8_str();
-        return false;
+        rDataId = id;
+        return true;
     }
     
     
@@ -188,7 +189,10 @@ bool ODi_Abi_Data::addObjectDataItem(UT_String& rDataId, const gchar** ppAtts, i
     UT_String_sprintf(rDataId, "MathLatex%d", objectID);
     
     // Add this id to the list
-    UT_ASSERT(m_href_to_id.ins(pHRef, rDataId.c_str()) == TRUE);
+    UT_ASSERT(m_href_to_id.insert(m_href_to_id.begin(),
+								  href_id_map_t::value_type(pHRef, 
+															rDataId.c_str())
+				  ) != m_href_to_id.end());
 
     _splitDirectoryAndFileName(pHRef, dirName, fileName);
 
