@@ -143,10 +143,10 @@ void ODi_Frame_ListenerState::_drawImage (const gchar** ppAtts,
     UT_ASSERT(pGraphicStyle);
     
     pChar = m_rElementStack.getStartTag(0)->getAttributeValue("text:anchor-type");
-    UT_ASSERT(pChar);
+    UT_ASSERT_HARMLESS(pChar);
     
-    if ( !strcmp(pChar, "as-char") ||
-         !strcmp(pChar, "char")) {
+    if ( pChar && (!strcmp(pChar, "as-char") ||
+         !strcmp(pChar, "char"))) {
         // In-line wrapping.
         // No frames are used on AbiWord for in-line wrapping.
         // It uses a <image> tag right in the paragraph text.
@@ -252,10 +252,10 @@ void ODi_Frame_ListenerState::_drawObject (const gchar** ppAtts,
     UT_ASSERT(pGraphicStyle);
     
     pChar = m_rElementStack.getStartTag(0)->getAttributeValue("text:anchor-type");
-    UT_ASSERT(pChar);
+    UT_ASSERT_HARMLESS(pChar);
     
-    if ( !strcmp(pChar, "as-char") ||
-         !strcmp(pChar, "char")) {
+    if ( pChar && (!strcmp(pChar, "as-char") ||
+         !strcmp(pChar, "char"))) {
         // In-line wrapping.
         // No frames are used on AbiWord for in-line wrapping.
         // It uses a <image> tag right in the paragraph text.
@@ -393,13 +393,14 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
     const gchar* pStyleName;
     const ODi_Style_Style* pGraphicStyle;
     const UT_UTF8String* pWrap;
+    const UT_UTF8String* pBackgroundColor;
     const gchar* pVal;
     
     pStyleName = m_rElementStack.getStartTag(0)->getAttributeValue("draw:style-name");
     UT_ASSERT(pStyleName);
     
     pGraphicStyle = m_pStyles->getGraphicStyle(pStyleName, m_bOnContentStream);
-    UT_ASSERT(pGraphicStyle);
+    UT_return_val_if_fail(pGraphicStyle, false);
     
     pWrap = pGraphicStyle->getWrap(false);
                                                     
@@ -423,10 +424,16 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
     }
 
 
+    pBackgroundColor = pGraphicStyle->getBackgroundColor();
+    if(pBackgroundColor && pBackgroundColor->length()) {
+        rProps += "; background-color:";
+        rProps += pBackgroundColor->utf8_str();
+    }
+
     
     pVal = m_rElementStack.getStartTag(0)->getAttributeValue("text:anchor-type");
-    UT_ASSERT(pVal);
-    if (!strcmp(pVal, "paragraph")) {
+    UT_ASSERT_HARMLESS(pVal);
+    if (pVal && !strcmp(pVal, "paragraph")) {
         rProps += "; position-to:block-above-text";
         
         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:x");
@@ -441,7 +448,7 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
             rProps += pVal;
         }
         
-    } else if (!strcmp(pVal, "page")) {
+    } else if (pVal && !strcmp(pVal, "page")) {
         rProps += "; position-to:page-above-text";
         
         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:x");
@@ -479,17 +486,17 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
             if (UT_determineDimension(pVal, DIM_none) == DIM_PERCENT) {
                 // TODO: Do the conversion from percentage to a real
                 //       unit (ie: "cm" or "in").
-                UT_ASSERT(UT_NOT_IMPLEMENTED);
+                UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
             }
         }
     } else {
         if (UT_determineDimension(pVal, DIM_none) == DIM_PERCENT) {
             // TODO: Do the conversion from percentage to a real
             //       unit (ie: "cm" or "in").
-            UT_ASSERT(UT_NOT_IMPLEMENTED);
+            UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
         }
     }
-    UT_ASSERT(pVal); // Is it really ok to not have a defined width?
+    UT_ASSERT_HARMLESS(pVal); // Is it really ok to not have a defined width?
     if (pVal) {
         rProps += "; frame-width:";
         rProps += pVal;
@@ -505,14 +512,14 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
             if (UT_determineDimension(pVal, DIM_none) == DIM_PERCENT) {
                 // TODO: Do the conversion from percentage to a real
                 //       unit (ie: "cm" or "in").
-                UT_ASSERT(UT_NOT_IMPLEMENTED);
+                UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
             }
         }
     } else {
         if (UT_determineDimension(pVal, DIM_none) == DIM_PERCENT) {
             // TODO: Do the conversion from percentage to a real
             //       unit (ie: "cm" or "in").
-            UT_ASSERT(UT_NOT_IMPLEMENTED);
+            UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
         }
     }
     if (pVal) {
