@@ -55,9 +55,9 @@ ODi_StreamListener::ODi_StreamListener(PD_Document* pAbiDocument,
                                      m_pCurrentState(NULL),
                                      m_deleteCurrentWhenPop(false)
 {
-    UT_ASSERT(m_pAbiDocument);
-    UT_ASSERT(m_pGsfInfile);
-    UT_ASSERT(m_pStyles);
+    UT_ASSERT_HARMLESS(m_pAbiDocument);
+    UT_ASSERT_HARMLESS(m_pGsfInfile);
+    UT_ASSERT_HARMLESS(m_pStyles);
 
 
     // This is done for supporting nested StreamListeners, used when we are
@@ -431,7 +431,7 @@ ODi_ListenerState* ODi_StreamListener::_createState(const char* pStateName) {
     if (!strcmp("StylesStream", pStateName)) {
         
         pState = new ODi_StylesStream_ListenerState(m_pAbiDocument, m_pGsfInfile,
-                                                   m_pStyles, *m_pElementStack);
+                                                   m_pStyles, *m_pElementStack, m_rAbiData);
         
     } else if (!strcmp("MetaStream", pStateName)) {
         
