@@ -399,9 +399,11 @@ void ODi_Style_Style::_parse_style_textProperties(const gchar** ppProps) {
 
     pVal = UT_getAttribute("style:text-position", ppProps);
     if(pVal) {
+        int position = 0;
+
         if (strstr(pVal, "sub") || strstr(pVal, "-"))
             m_textPos = "subscript";
-        else if (strstr(pVal, "super"))
+        else if (strstr(pVal, "super") || ((sscanf(pVal, "%d%%", &position) == 1) && (position > 0)))
             m_textPos = "superscript";
         else 
             m_textPos = "normal";
@@ -448,6 +450,15 @@ void ODi_Style_Style::_parse_style_textProperties(const gchar** ppProps) {
         }
     }
 
+    // Note (for testing interoperability): OO.org doesn't correctly support hidden text:
+    // http://qa.openoffice.org/issues/show_bug.cgi?id=64237
+
+    pVal = UT_getAttribute ("text:display", ppProps);
+    if(pVal) {
+        if (!strcmp(pVal, "none")) {
+            m_display = pVal;
+        }
+    }
 
     pVal = UT_getAttribute ("fo:background-color", ppProps);
     if(pVal) {
@@ -486,6 +497,11 @@ void ODi_Style_Style::_parse_style_graphicProperties(const gchar** ppProps) {
     if (pVal) {
         m_wrap = pVal;
     }
+
+    pVal = UT_getAttribute("fo:background-color", ppProps);
+    if (pVal) {
+        m_backgroundColor = pVal;
+    }
 }
 
 
@@ -642,7 +658,7 @@ void ODi_Style_Style::defineAbiStyle(PD_Document* pDocument) {
         pAttr[i++] = "C";
     } else {
         // Really shouldn't happen
-        UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+        UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
     }
     
     // AbiWord uses the display name
@@ -666,7 +682,7 @@ void ODi_Style_Style::defineAbiStyle(PD_Document* pDocument) {
     pAttr[i] = 0; // Signal the end of the array 
     
     ok = pDocument->appendStyle(pAttr);
-    UT_ASSERT(ok);
+    UT_ASSERT_HARMLESS(ok);
 }
 
 
@@ -687,7 +703,7 @@ void ODi_Style_Style::buildAbiPropsAttrString(ODi_FontFaceDecls& rFontFaceDecls)
             UT_DEBUGMSG(("*** [OpenDocument] no parent style to resolve '%s'\n",
                 m_fontSize.utf8_str()));
                 
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             
             // Ignore its value then
             m_fontSize.clear();
@@ -739,13 +755,11 @@ void ODi_Style_Style::buildAbiPropsAttrString(ODi_FontFaceDecls& rFontFaceDecls)
     APPEND_STYLE("text-position: ", m_textPos);
     
     if (!m_fontName.empty()) {
-        const UT_UTF8String* pFontFamily;
+        const std::string & fontFamily = rFontFaceDecls.getFontFamily(m_fontName);
         
-        pFontFamily = rFontFaceDecls.getFontFamily(m_fontName);
-        
-        UT_ASSERT(pFontFamily);
-        if (pFontFamily!=NULL) {
-            APPEND_STYLE("font-family: ", (*pFontFamily));
+        UT_ASSERT_HARMLESS(!fontFamily.empty());
+        if (!fontFamily.empty()) {
+            APPEND_STYLE("font-family: ", fontFamily);
         }
     }
     
@@ -753,6 +767,11 @@ void ODi_Style_Style::buildAbiPropsAttrString(ODi_FontFaceDecls& rFontFaceDecls)
     APPEND_STYLE("lang: ", m_lang);
     APPEND_STYLE("font-style: ", m_fontStyle);
     APPEND_STYLE("font-weight: ", m_fontWeight);
+
+    // AbiWord hangs when a paragraph has a "display:none" property
+    if (m_family.length() && !strcmp("text", m_family.utf8_str())) {
+        APPEND_STYLE("display: ", m_display);
+    }
     
     // <style:section-properties />
     APPEND_STYLE("columns: ", m_columns);
