@@ -151,6 +151,7 @@ public:
                !m_lang.empty() ||
                !m_fontStyle.empty() ||
                !m_fontWeight.empty() ||
+               !m_display.empty() ||
             
                !m_columns.empty() ||
                !m_columnGap.empty() ||
@@ -342,6 +343,7 @@ private:
     UT_UTF8String m_lang;
     UT_UTF8String m_fontStyle;
     UT_UTF8String m_fontWeight;
+    UT_UTF8String m_display; //text:display
 
 
     // fo:background-color
