@@ -65,8 +65,8 @@ ODi_TextContent_ListenerState::ODi_TextContent_ListenerState (
                   m_alreadyDefinedAbiParagraphForList(false),
                   m_pendingNoteAnchorInsertion(false)
 {
-    UT_ASSERT(m_pAbiDocument);
-    UT_ASSERT(m_pStyles);
+    UT_ASSERT_HARMLESS(m_pAbiDocument);
+    UT_ASSERT_HARMLESS(m_pStyles);
 }
 
 
@@ -75,7 +75,7 @@ ODi_TextContent_ListenerState::ODi_TextContent_ListenerState (
  */
 ODi_TextContent_ListenerState::~ODi_TextContent_ListenerState() {
 
-    UT_ASSERT(m_tablesOfContentProps.getItemCount()==0);
+    UT_ASSERT_HARMLESS(m_tablesOfContentProps.getItemCount()==0);
    
     if (m_tablesOfContentProps.getItemCount() > 0) {
         UT_VECTOR_PURGEALL(UT_UTF8String*, m_tablesOfContentProps);
@@ -150,13 +150,14 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         }
         
         pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
-        UT_ASSERT(pStyle);
+        UT_ASSERT_HARMLESS(pStyle);
         
         if (pStyle && (pStyle->isAutomatic())) {
 
             if (pStyle->getParent() != NULL) {
-                m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
-                                    pStyle->getParent()->getDisplayName());
+
+                m_headingStyles[pOutlineLevel] = 
+					pStyle->getParent()->getDisplayName().utf8_str();
             } else {
                 UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
                 // This is not expected from a well formed file.
@@ -166,11 +167,8 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
             }
             
         } else if (pStyle) {
-            m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
-                                pStyle->getDisplayName());
-        } else {
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
-            // pStyle is NULL
+            m_headingStyles[pOutlineLevel] =
+				pStyle->getDisplayName().utf8_str();
         }
         
         // It's so big that it deserves its own function.
@@ -241,7 +239,7 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         
         if (!pStyleName) {
             // I haven't seen default styles for "text" family.
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             
         } else {
             pStyle = m_pStyles->getTextStyle(pStyleName, m_bOnContentStream);
@@ -292,9 +290,36 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         
         _flush ();
         const gchar * pName = UT_getAttribute ("text:name", ppAtts);
-        _insertBookmark (pName, "start");
-        _insertBookmark (pName, "end");
+
+        if(pName) {
+            _insertBookmark (pName, "start");
+            _insertBookmark (pName, "end");
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
         
+    } else if (!strcmp(pName, "text:bookmark-start")) {
+
+        _flush ();
+        const gchar * pName = UT_getAttribute ("text:name", ppAtts);
+
+        if(pName) {
+            _insertBookmark (pName, "start");
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
+
+    } else if (!strcmp(pName, "text:bookmark-end")) {
+
+        _flush ();
+        const gchar * pName = UT_getAttribute ("text:name", ppAtts);
+
+        if(pName) {
+            _insertBookmark (pName, "end");
+        } else {
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
+
     } else if (!strcmp(pName, "text:date") ||
             !strcmp(pName, "text:time") ||
             !strcmp(pName, "text:page-number") ||
@@ -435,7 +460,7 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
             }
 
         } else {
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             // TODO: Figure out what to do then.
         }
         
@@ -476,14 +501,14 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         const gchar* pNoteClass;
         
         pNoteClass = m_rElementStack.getStartTag(0)->getAttributeValue("text:note-class");
-        UT_ASSERT(pNoteClass != NULL);
+        UT_ASSERT_HARMLESS(pNoteClass != NULL);
         
-        if (!strcmp(pNoteClass, "footnote")) {
+        if (pNoteClass && !strcmp(pNoteClass, "footnote")) {
             isFootnote = true;
-        } else if (!strcmp(pNoteClass, "endnote")) {
+        } else if (pNoteClass && !strcmp(pNoteClass, "endnote")) {
             isFootnote = false;
         } else {
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             // Unrecognized note class.
         }
         
@@ -656,14 +681,14 @@ void ODi_TextContent_ListenerState::endElement (const gchar* pName,
         const gchar* pNoteClass;
         
         pNoteClass = m_rElementStack.getStartTag(1)->getAttributeValue("text:note-class");
-        UT_ASSERT(pNoteClass != NULL);
+        UT_ASSERT_HARMLESS(pNoteClass != NULL);
         
-        if (!strcmp(pNoteClass, "footnote")) {
+        if (pNoteClass && !strcmp(pNoteClass, "footnote")) {
             ok = m_pAbiDocument->appendStrux(PTX_EndFootnote, NULL);
-        } else if (!strcmp(pNoteClass, "endnote")) {
+        } else if (pNoteClass && !strcmp(pNoteClass, "endnote")) {
             ok = m_pAbiDocument->appendStrux(PTX_EndEndnote, NULL);
         } else {
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             // Unrecognized note class.
         }
         
@@ -701,6 +726,8 @@ void ODi_TextContent_ListenerState::charData (
 void ODi_TextContent_ListenerState::_insertBookmark (const gchar* pName,
                                              const gchar* pType)
 {
+    UT_return_if_fail(pName && pType);
+
     const gchar* pPropsArray[5];
     pPropsArray[0] = (gchar *)"name";
     pPropsArray[1] = pName;
@@ -848,6 +875,7 @@ void ODi_TextContent_ListenerState::_openAbiSection(
                                          const UT_UTF8String* pMasterPageName) {
 
     UT_UTF8String allProps;
+    UT_UTF8String dataID;
     
 
     const ODi_Style_MasterPage* pMasterPageStyle = NULL;
@@ -858,6 +886,7 @@ void ODi_TextContent_ListenerState::_openAbiSection(
         
         if (pMasterPageStyle && pMasterPageStyle->getPageLayout()) {
             allProps = pMasterPageStyle->getSectionProps();
+            dataID = pMasterPageStyle->getSectionDataID();
             UT_ASSERT(!allProps.empty());
         }
         
@@ -872,11 +901,12 @@ void ODi_TextContent_ListenerState::_openAbiSection(
         // multiple page formats anyway.
         
         pMasterPageStyle = m_pStyles->getMasterPageStyle("Standard");
-        UT_ASSERT(pMasterPageStyle);
+        UT_return_if_fail(pMasterPageStyle);
         
         UT_ASSERT(pMasterPageStyle->getPageLayout());
         
         allProps = pMasterPageStyle->getSectionProps();
+        dataID = pMasterPageStyle->getSectionDataID();
         UT_ASSERT(!allProps.empty());
 
         m_openedFirstAbiSection = true;
@@ -922,6 +952,11 @@ void ODi_TextContent_ListenerState::_openAbiSection(
             atts[i++] = "footer";
             atts[i++] = pMasterPageStyle->getAWFooterSectionID().utf8_str();
         }
+
+        if (dataID.length()) {
+            atts[i++] = "strux-image-dataid";
+            atts[i++] = dataID.utf8_str();
+        }
     }
     
     atts[i] = 0; // No more attributes.
@@ -1188,7 +1223,7 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* pName,
                 ppAtts[1] = "endnote_anchor";
                 ppAtts[2] = "endnote-id";
             } else {
-                UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+                UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
                 // Unrecognized note class.
             }
             ppAtts[3] = m_currentNoteId.utf8_str();
@@ -1252,7 +1287,7 @@ void ODi_TextContent_ListenerState::_defineAbiTOCHeadingStyles() {
     pf_Frag_Strux* pTOCStrux;
     UT_UTF8String str;
     UT_UTF8String props;
-    const UT_UTF8String* pStyleName;
+    std::string styleName;
     bool ok;
     
     count = m_tablesOfContent.getItemCount();
@@ -1262,11 +1297,11 @@ void ODi_TextContent_ListenerState::_defineAbiTOCHeadingStyles() {
         
         for (j=1; j<5; j++) {
             UT_UTF8String_sprintf(str, "%d", j);
-            pStyleName = m_headingStyles[str];
+            styleName = m_headingStyles[str.utf8_str()];
 
-            if (pStyleName) {
+            if (!styleName.empty()) {
                 UT_UTF8String_sprintf(str, "toc-source-style%d:%s", j,
-                                      pStyleName->utf8_str());
+                                      styleName.c_str());
                 
                 if (!props.empty()) {
                     props += "; ";
