@@ -24,13 +24,15 @@
 #ifndef _ODI_TEXTCONTENT_LISTENERSTATE_H_
 #define _ODI_TEXTCONTENT_LISTENERSTATE_H_
 
+#include <string>
+#include <map>
+
 // Internal includes
 #include "ODi_ListenerState.h"
 
 // AbiWord includes
 #include <ut_types.h>
 #include <ut_stack.h>
-#include <ut_IntStrMap.h>
 
 // External includes
 #include <gsf/gsf.h>
@@ -155,7 +157,7 @@ private:
     UT_GenericVector<UT_UTF8String*> m_tablesOfContentProps;
     // Maps a heading level with its style name
     // e.g.: "1" -> "Heading_20_1"
-    UT_UTF8Hash m_headingStyles;
+    std::map<std::string, std::string> m_headingStyles;
     ODi_TableOfContent_ListenerState* m_pCurrentTOCParser;
 
     // Valued as "true" if it is parsing XML content inside a
