@@ -80,6 +80,8 @@ public:
    virtual void closeBlock() = 0;
    virtual void openSpan(UT_String & props, UT_String & font) = 0;
    virtual void closeSpan() = 0;   
+   virtual void openHyperlink(const PP_AttrProp* pAP) = 0;
+   virtual void closeHyperlink() = 0;
 };
 
 class OO_Listener : public PL_Listener
@@ -106,6 +108,8 @@ private:
    void _closeSpan();
    void _openBlock(PT_AttrPropIndex apiSpan);
    void _closeBlock();
+   void _openHyperlink(const PP_AttrProp* pAP);
+   void _closeHyperlink();
 
    PD_Document * m_pDocument;
    IE_Exp_OpenWriter * m_pie;
@@ -113,6 +117,7 @@ private:
 
    bool m_bInBlock;
    bool m_bInSpan;
+   bool m_bInHyperlink;
 };
 
 class OO_StylesContainer
@@ -154,6 +159,8 @@ public:
    virtual void closeBlock() {};
    virtual void openSpan(UT_String & props, UT_String & font);
    virtual void closeSpan() {}
+   virtual void openHyperlink(const PP_AttrProp* pAP) {}
+   virtual void closeHyperlink() {}
 
 private:
    OO_StylesContainer *m_pStylesContainer;
@@ -173,6 +180,8 @@ public:
    virtual void closeBlock();
    virtual void openSpan(UT_String & props, UT_String & font);
    virtual void closeSpan();
+   virtual void openHyperlink(const PP_AttrProp* pAP);
+   virtual void closeHyperlink();
 
 private:
    GsfOutput * m_pContentStream;
