@@ -180,12 +180,17 @@ private:
     val = UT_getAttribute ("fo:margin-bottom", props);
     if (val)
       m_marginBottom = UT_String_sprintf("page-margin-bottom: %s;", val);
+
+    val = UT_getAttribute ("fo:background-color", props);
+    if (val)
+      m_backgroundColor = UT_String_sprintf("background-color: %s;", val);
 	
 #define APPEND_STYLE(sty) if (sty.size()) m_sectionProps += sty;
     APPEND_STYLE(m_marginLeft);
     APPEND_STYLE(m_marginTop);
     APPEND_STYLE(m_marginRight);
     APPEND_STYLE(m_marginBottom);
+    APPEND_STYLE(m_backgroundColor);
 #undef APPEND_STYLE
     if (m_sectionProps.size () > 0)
       m_sectionProps [m_sectionProps.size()-1] = 0; 
@@ -200,6 +205,7 @@ private:
   UT_String m_marginTop;
   UT_String m_marginRight;
   UT_String m_marginBottom;
+  UT_String m_backgroundColor;
   
   static const int MAX_PAGE_ATTS = 13; // 2*(width height orientation pagetype units page-scale) 0 
   const gchar * m_pageAtts[MAX_PAGE_ATTS];
@@ -1265,6 +1271,11 @@ public:
 	m_charData += UCS_LF;
 	_flush ();
       }
+    else if (!strcmp(name, "text:tab-stop"))
+      {
+	m_charData += UCS_TAB;
+	_flush ();
+      }
     else if (!strcmp(name, "text:ordered-list") || !strcmp(name, "text:unordered-list"))
       {
 	const gchar * list_atts[15];
@@ -1302,6 +1313,7 @@ public:
       }
     else if (!strcmp(name, "text:a"))
       {
+	_flush();
 	const gchar * xlink_atts[3];
 	xlink_atts[0] = "xlink:href";
 	xlink_atts[1] = UT_getAttribute("xlink:href", atts);
@@ -1312,8 +1324,44 @@ public:
     {
       _flush ();
       const gchar * name = UT_getAttribute ("text:name", atts);
-      _insertBookmark (name, "start");
-      _insertBookmark (name, "end");
+
+      if(name)
+      {
+        _insertBookmark (name, "start");
+        _insertBookmark (name, "end");
+      }
+      else
+      {
+        UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+      }
+    }
+    else if (!strcmp(name, "text:bookmark-start"))
+    {
+      _flush ();
+      const gchar * name = UT_getAttribute ("text:name", atts);
+
+      if(name)
+      {
+        _insertBookmark (name, "start");
+      }
+      else
+      {
+        UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+      }
+    }
+    else if (!strcmp(name, "text:bookmark-end"))
+    {
+      _flush ();
+      const gchar * name = UT_getAttribute ("text:name", atts);
+
+      if(name)
+      {
+        _insertBookmark (name, "end");
+      }
+      else
+      {
+        UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+      }
     }
     else if (!strcmp(name, "text:table-of-content"))
     {
@@ -1505,7 +1553,7 @@ private:
 
     const char * mimetype 	= g_strdup ("image/png");
     FG_Graphic* pFG		= 0;
-    UT_ByteBuf * pictData       = 0;
+    const UT_ByteBuf * pictData       = 0;
     
     UT_String propBuffer;
     UT_String propsName;
@@ -1590,6 +1638,8 @@ private:
   
   void _insertBookmark (const gchar * name, const gchar * type)
     {
+	UT_return_if_fail(name && type);
+
 	const gchar* propsArray[5];
 	propsArray[0] = (gchar *)"name";
 	propsArray[1] = name;
