@@ -35,7 +35,7 @@
 #include "ie_impexp_Applix.h"
 
 // these should both be case insensitive
-#define AX_STR_CMP(x, y) UT_strcmp((x), (y))
+#define AX_STR_CMP(x, y) strcmp((x), (y))
 #define AX_STRN_CMP(x, y, z) strncmp((x), (y), (z))
 
 #define APPLIX_LINE_LENGTH 80 // applix does 80 to a line
@@ -57,7 +57,7 @@ IE_Imp_Applix_Sniffer::IE_Imp_Applix_Sniffer (const char * name) :
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_Applix_Sniffer__SuffixConfidence[] = {
 	{ "aw", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_Applix_Sniffer::getSuffixConfidence ()
@@ -68,7 +68,7 @@ const IE_SuffixConfidence * IE_Imp_Applix_Sniffer::getSuffixConfidence ()
 // supported mimetypes
 static IE_MimeConfidence IE_Imp_Applix_Sniffer__MimeConfidence[] = {
 	{ IE_MIME_MATCH_FULL, 	IE_MIMETYPE_Applix, UT_CONFIDENCE_GOOD 	},
-	{ IE_MIME_MATCH_BOGUS, 	NULL, 				UT_CONFIDENCE_ZILCH }
+	{ IE_MIME_MATCH_BOGUS, 	"", 				UT_CONFIDENCE_ZILCH }
 };
 
 const IE_MimeConfidence * IE_Imp_Applix_Sniffer::getMimeConfidence ()
