@@ -51,10 +51,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	{
 	  m_impSniffer = new IE_ImpGraphicBMP_Sniffer();
 	}
-	else
-	{
-		m_impSniffer->ref();
-	}
 
 	mi->name = "BMP Import Plugin";
 	mi->desc = "Import Windows Bitmap Images";
@@ -78,10 +74,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	UT_ASSERT (m_impSniffer);
 
 	IE_ImpGraphic::unregisterImporter (m_impSniffer);
-	if (!m_impSniffer->unref())
-	{
-		m_impSniffer = 0;
-	}
+	delete m_impSniffer;
+	m_impSniffer = 0;
 
 	return 1;
 }
