@@ -831,10 +831,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
     {
       m_impSniffer = new IE_ImpGraphicWin32Native_Sniffer();
     }
-  else
-    {
-      m_impSniffer->ref();
-    }
   
   mi->name = "BMP, JPG, GIF Win32 Import Plugin";
   mi->desc = "Import JPG, GIF, WMF Images";
@@ -858,11 +854,9 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
   UT_ASSERT (m_impSniffer);
 
   IE_ImpGraphic::unregisterImporter (m_impSniffer);
-  if (!m_impSniffer->unref())
-    {
-      m_impSniffer = 0;
-    }
-  
+  delete m_impSniffer;
+  m_impSniffer = 0;
+
   return 1;
 }
 
