@@ -182,10 +182,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
     {
     	m_impSniffer = new IE_Imp_Hancom_Sniffer ();
     }
-    else
-    {
-	m_impSniffer->ref();
-    }
 
     mi->name    = "Hancom .hwp file importer";
     mi->desc    = "Imports Hancom binary (OLE) documents";
@@ -209,10 +205,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
     UT_ASSERT (m_impSniffer);
 
     IE_Imp::unregisterImporter (m_impSniffer);
-    if(!m_impSniffer->unref())
-    {
+	delete m_impSniffer;
 	m_impSniffer = 0;
-    }
 
     return 1;
 }
