@@ -136,7 +136,7 @@ IE_Exp_KWord_1_Sniffer::IE_Exp_KWord_1_Sniffer (const char * name) :
 
 UT_Confidence_t IE_Exp_KWord_1_Sniffer::supportsMIME (const char * szMIME)
 {
-  if (UT_strcmp (IE_FileInfo::mapAlias (szMIME), IE_MIMETYPE_KWord) == 0)
+  if (strcmp (IE_FileInfo::mapAlias (szMIME), IE_MIMETYPE_KWord) == 0)
     {
       return UT_CONFIDENCE_GOOD;
     }
@@ -145,7 +145,7 @@ UT_Confidence_t IE_Exp_KWord_1_Sniffer::supportsMIME (const char * szMIME)
 
 bool IE_Exp_KWord_1_Sniffer::recognizeSuffix(const char * szSuffix)
 {
-	return (!UT_stricmp(szSuffix,".kwd"));
+	return (!g_ascii_strcasecmp(szSuffix,".kwd"));
 }
 
 UT_Error IE_Exp_KWord_1_Sniffer::constructExporter(PD_Document * pDocument,
@@ -303,11 +303,11 @@ bool s_KWord_1_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 		const PP_AttrProp* pAP = NULL;
 		if (m_pDocument->getAttrProp(indexAP, &pAP) && pAP)
 		{
-			const XML_Char* pszSectionType = NULL;
+			const gchar* pszSectionType = NULL;
 			pAP->getAttribute("type", pszSectionType);
 			if (
 				!pszSectionType
-				|| (0 == UT_strcmp(pszSectionType, "doc"))
+				|| (0 == strcmp(pszSectionType, "doc"))
 				)
 			{
 				_openSection(pcr->getIndexAP());
@@ -481,7 +481,7 @@ abiPageSizeToKoPageFormat (fp_PageSize abi_page_size)
 void s_KWord_1_Listener::_writeMarginSize(PT_AttrPropIndex api, char * name)
 {
         UT_String buf;
-	const XML_Char * szValue;
+	const gchar * szValue;
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
 	UT_ASSERT((bHaveProp));
@@ -577,9 +577,9 @@ void s_KWord_1_Listener::_handleDataItems(void)
 	{	  	  
 	  UT_UTF8String fname;	  
 	  
-	  if (!UT_strcmp(szMimeType, "image/svg+xml"))
+	  if (!strcmp(szMimeType, "image/svg+xml"))
 	      UT_UTF8String_sprintf(fname, "%s-%d.svg", m_pie->getFileName(), k);
-	  if (!UT_strcmp(szMimeType, "application/mathml+xml"))
+	  if (!strcmp(szMimeType, "application/mathml+xml"))
 	    UT_UTF8String_sprintf(fname, "%s-%d.mathml", m_pie->getFileName(), k);
 	  else // PNG Image
 	    UT_UTF8String_sprintf(fname, "%s-%d.png", m_pie->getFileName(), k);
@@ -700,7 +700,7 @@ void s_KWord_1_Listener::_openBlock(PT_AttrPropIndex api)
 	// FIXME: does AbiWord support this?
 	if (bHaveProp && pAP)
 	{
-		const XML_Char * szValue;
+		const gchar * szValue;
 	
 		// FLOW
 		// <FLOW align="left,right,center,justify"/>
@@ -835,10 +835,10 @@ void s_KWord_1_Listener::_openBlock(PT_AttrPropIndex api)
 	// e.g., <PAGEBREAKING linesTogether="true" keepWithNext="true"/>
 		bool bLinesTogether=false;
 		if (pAP->getProperty("keep-together", szValue))
-			bLinesTogether = (UT_stricmp(szValue,"true") == 0);
+			bLinesTogether = (g_ascii_strcasecmp(szValue,"true") == 0);
 		bool bKeepWithNext=false;
 		if (pAP->getProperty("keep-with-next", szValue))
-			bKeepWithNext = (UT_stricmp(szValue,"true") == 0);
+			bKeepWithNext = (g_ascii_strcasecmp(szValue,"true") == 0);
 	// FIXME: I should probably run this if and only if the above properties
 	// exist (dealing with styles)
 		if (bLinesTogether || bKeepWithNext)
@@ -970,7 +970,7 @@ void s_KWord_1_Listener::_openSpan(PT_AttrPropIndex api, PT_BlockOffset pos, UT_
 	if (bHaveProp && pAP)
 	{
 		// query and output properties
-		const XML_Char * szValue = 0;
+		const gchar * szValue = 0;
 
 		if (pAP->getProperty("color", szValue))
 		{
@@ -1035,7 +1035,7 @@ void s_KWord_1_Listener::_openSpan(PT_AttrPropIndex api, PT_BlockOffset pos, UT_
 		if (pAP->getProperty("font-weight", szValue))
 		{
 			m_sFormats += "<WEIGHT value=\"";
-			if (!UT_stricmp(static_cast<const char *>(szValue), "bold"))
+			if (!g_ascii_strcasecmp(static_cast<const char *>(szValue), "bold"))
 				m_sFormats += "75";
 			else
 				m_sFormats += "50";
@@ -1046,7 +1046,7 @@ void s_KWord_1_Listener::_openSpan(PT_AttrPropIndex api, PT_BlockOffset pos, UT_
 		if (pAP->getProperty("font-style", szValue))
 		{
 			m_sFormats += "<ITALIC value=\"";
-			if (!UT_stricmp(static_cast<const char *>(szValue), "italic"))
+			if (!g_ascii_strcasecmp(static_cast<const char *>(szValue), "italic"))
 				m_sFormats += "1";
 			else
 				m_sFormats += "0";
@@ -1070,9 +1070,9 @@ void s_KWord_1_Listener::_openSpan(PT_AttrPropIndex api, PT_BlockOffset pos, UT_
 		// <VERTALIGN value="0"/> 0=normal, 1=subscript, 2=superscript
 		if (pAP->getProperty("text-position", szValue))
 		{
-			if (!UT_stricmp (szValue, "subscript"))
+			if (!g_ascii_strcasecmp (szValue, "subscript"))
 				m_sFormats += "<VERTALIGN value=\"1\"/>\n";
-			else if (!UT_stricmp (szValue, "superscript"))
+			else if (!g_ascii_strcasecmp (szValue, "superscript"))
 				m_sFormats += "<VERTALIGN value=\"2\"/>\n";
 			else
 				m_sFormats += "<VERTALIGN value=\"0\"/>\n";
