@@ -60,7 +60,7 @@ IE_Imp_KWord_1_Sniffer::IE_Imp_KWord_1_Sniffer (const char * name) :
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_KWord_1_Sniffer__SuffixConfidence[] = {
 	{ "kwd", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_KWord_1_Sniffer::getSuffixConfidence ()
@@ -72,7 +72,7 @@ const IE_SuffixConfidence * IE_Imp_KWord_1_Sniffer::getSuffixConfidence ()
 static IE_MimeConfidence IE_Imp_KWord_1_Sniffer__MimeConfidence[] = {
 	{ IE_MIME_MATCH_FULL, 	IE_MIMETYPE_KWord, 		UT_CONFIDENCE_GOOD 	}, 
 	{ IE_MIME_MATCH_FULL, 	"application/x-kword", 	UT_CONFIDENCE_GOOD 	},
-	{ IE_MIME_MATCH_BOGUS, 	NULL, 					UT_CONFIDENCE_ZILCH }
+	{ IE_MIME_MATCH_BOGUS, 	"", 					UT_CONFIDENCE_ZILCH }
 };
 
 const IE_MimeConfidence * IE_Imp_KWord_1_Sniffer::getMimeConfidence ()
@@ -122,12 +122,12 @@ IE_Imp_KWord_1::IE_Imp_KWord_1(PD_Document *pDocument) : IE_Imp_XML(pDocument, t
 {
 }
 
-void IE_Imp_KWord_1::charData(const XML_Char *s, int len)
+void IE_Imp_KWord_1::charData(const gchar *s, int len)
 {
   X_EatIfAlreadyError();	// xml parser keeps running until buffer consumed
 
-  UT_ASSERT(sizeof(XML_Char) == sizeof(UT_Byte));
-  UT_ASSERT(sizeof(XML_Char) != sizeof(UT_UCSChar));
+  UT_ASSERT(sizeof(gchar) == sizeof(UT_Byte));
+  UT_ASSERT(sizeof(gchar) != sizeof(UT_UCSChar));
 
   if(!m_bInText)
     return;
@@ -180,7 +180,7 @@ void IE_Imp_KWord_1::charData(const XML_Char *s, int len)
 	  m_charDataSeen[m_lenCharDataSeen++] = currentChar;
 	  if (m_lenCharDataSeen == m_lenCharDataExpected)
 	    {
-	      buf += UT_decodeUTF8char(m_charDataSeen,m_lenCharDataSeen);
+	      buf += g_utf8_get_char(m_charDataSeen);
 	      m_lenCharDataSeen = 0;
 	    }
 	}
@@ -344,14 +344,14 @@ kVertAlignToTextPos ( const char * sz )
 /*****************************************************************/
 /*****************************************************************/
 
-void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
+void IE_Imp_KWord_1::startElement(const gchar *name, const gchar **atts)
 {
   // xml parser keeps running until buffer consumed
   X_EatIfAlreadyError();
 
   UT_uint32 tokenIndex = _mapNameToToken(name, s_Tokens, TokenTableSize);
 
-  const XML_Char *pVal = 0;
+  const gchar *pVal = 0;
 
   switch (tokenIndex)
   {
@@ -382,7 +382,7 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
     case TT_COLOR:
       {
 
-        const XML_Char *p = NULL;
+        const gchar *p = NULL;
 	int red, green, blue;
 	red = green = blue = 0;
 	p = _getXMLPropValue("red", atts);
@@ -431,12 +431,12 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
 	if(m_szSectProps.size() >= 2)
 		m_szSectProps[m_szSectProps.size() - 2] = 0; // knock off the final ';'
 
-	const XML_Char *propsArray[3];
-	propsArray[0] = static_cast<const XML_Char *>("props");
-	propsArray[1] = static_cast<const XML_Char *>(m_szSectProps.c_str());
+	const gchar *propsArray[3];
+	propsArray[0] = static_cast<const gchar *>("props");
+	propsArray[1] = static_cast<const gchar *>(m_szSectProps.c_str());
 	propsArray[2] = 0;
 
-	X_CheckError(appendStrux(PTX_Section,static_cast<const XML_Char**>(&propsArray[0])));
+	X_CheckError(appendStrux(PTX_Section,static_cast<const gchar**>(&propsArray[0])));
 	m_szSectProps.clear(); //reset cached properties
 
 	UT_DEBUGMSG(("DOM: CREATED SECTION\n"));
@@ -484,7 +484,7 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
       {
         xxx_UT_DEBUGMSG(("ABIDEBUG: begin PAPER\n"));
 	
-	const XML_Char * pVal = NULL;
+	const gchar * pVal = NULL;
 
 	pVal = _getXMLPropValue("format", atts);
 	if(pVal)
@@ -535,7 +535,7 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
 
 	// margins
 
-	const XML_Char * pVal = NULL;
+	const gchar * pVal = NULL;
 
 	pVal = _getXMLPropValue("right", atts);
 	if(pVal)
@@ -589,7 +589,7 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
       {
         xxx_UT_DEBUGMSG(("ABIDEBUG: begin PARAGRPAH\n"));
 
-        const XML_Char *pVal = NULL;
+        const gchar *pVal = NULL;
 
         pVal = _getXMLPropValue("value", atts);
         if (pVal)
@@ -602,7 +602,7 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
 	if(m_ParaProps.size() >= 2)
 		m_ParaProps[m_ParaProps.size()-2] = 0;
 	
-	const XML_Char * props[3];
+	const gchar * props[3];
 	props[0] = "props";
 	props[1] = m_ParaProps.c_str();
 	props[2] = 0;
@@ -646,39 +646,39 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
       
     case TT_ITALIC:
       {
-        pVal = static_cast<const XML_Char *>(_getXMLPropValue("value", atts));
-        if (pVal && UT_strcmp(pVal, "1") == 0 )
+        pVal = static_cast<const gchar *>(_getXMLPropValue("value", atts));
+        if (pVal && strcmp(pVal, "1") == 0 )
         m_szCharProps += "font-style:italic; ";
         break;
       }
       
     case TT_UNDERLINE:
       {
-        pVal = static_cast<const XML_Char *>(_getXMLPropValue("value", atts));
-        if (pVal && UT_strcmp(pVal, "1") == 0 )
+        pVal = static_cast<const gchar *>(_getXMLPropValue("value", atts));
+        if (pVal && strcmp(pVal, "1") == 0 )
         m_szCharProps += "text-decoration:underline; ";
         break;
       }
       
     case TT_WEIGHT:
       {
-        pVal = static_cast<const XML_Char *>(_getXMLPropValue("value", atts));
-        if ( pVal && UT_strcmp ( pVal, "75" ) == 0 )
+        pVal = static_cast<const gchar *>(_getXMLPropValue("value", atts));
+        if ( pVal && strcmp ( pVal, "75" ) == 0 )
         m_szCharProps += "font-weight:bold; ";
         break;
       }
       
     case TT_STRIKEOUT:
       {
-        pVal = static_cast<const XML_Char *>(_getXMLPropValue("value", atts));
-        if (pVal && UT_strcmp(pVal, "1") == 0 )
+        pVal = static_cast<const gchar *>(_getXMLPropValue("value", atts));
+        if (pVal && strcmp(pVal, "1") == 0 )
         m_szCharProps += "text-decoration:strike-through; ";
         break;
       }
       
     case TT_FONT:
       {
-        pVal = static_cast<const XML_Char *>(_getXMLPropValue("name", atts));
+        pVal = static_cast<const gchar *>(_getXMLPropValue("name", atts));
         if (pVal)
         {
           m_szCharProps += "font-face:";
@@ -690,7 +690,7 @@ void IE_Imp_KWord_1::startElement(const XML_Char *name, const XML_Char **atts)
       
     case TT_SIZE:
       {
-        pVal = static_cast<const XML_Char *>(_getXMLPropValue("value", atts));
+        pVal = static_cast<const gchar *>(_getXMLPropValue("value", atts));
         if (pVal)
         {
           m_szCharProps += "font-size:";
@@ -725,7 +725,7 @@ void IE_Imp_KWord_1::_appendText()
     }
 }
 
-void IE_Imp_KWord_1::endElement(const XML_Char *name)
+void IE_Imp_KWord_1::endElement(const gchar *name)
 {
   X_EatIfAlreadyError();
 
@@ -778,7 +778,7 @@ void IE_Imp_KWord_1::endElement(const XML_Char *name)
 
     case TT_FORMAT:
     {
-      const XML_Char *propsArray[3];
+      const gchar *propsArray[3];
 
       if (m_szCharProps.size() == 0)
         {
@@ -790,8 +790,8 @@ void IE_Imp_KWord_1::endElement(const XML_Char *name)
 	if(m_szCharProps.size() >= 2)
 		m_szCharProps[m_szCharProps.size() - 2] = 0; // knock off the final ';'
 
-      propsArray[0] = static_cast<const XML_Char *>("props");
-      propsArray[1] = static_cast<const XML_Char *>(m_szCharProps.c_str());
+      propsArray[0] = static_cast<const gchar *>("props");
+      propsArray[1] = static_cast<const gchar *>(m_szCharProps.c_str());
       propsArray[2] = 0;
 
       xxx_UT_DEBUGMSG(("ABIDEBUG: formatting properties are: %s\n",propsArray[1]));
