@@ -2,7 +2,7 @@
 
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
- * Copyright (C) 2004 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -70,10 +70,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	{
 		m_sniffer = new IE_Exp_LaTeX_Sniffer ();
 	}
-	else
-	{
-		m_sniffer->ref();
-	}
 
 	mi->name = "LaTeX Exporter";
 	mi->desc = "Export LaTeX Documents";
@@ -94,13 +90,11 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	mi->author = 0;
 	mi->usage = 0;
 
-	UT_ASSERT (m_sniffer);
+	UT_return_val_if_fail (m_sniffer, 0);
 
 	IE_Exp::unregisterExporter (m_sniffer);
-	if (!m_sniffer->unref())
-	{
-		m_sniffer = 0;
-	}
+	delete m_sniffer;
+	m_sniffer = 0;
 
 	return 1;
 }
@@ -1203,15 +1197,15 @@ static bool _convertLettersToSymbols(char c, char *& subst)
 s_LaTeX_Listener::s_LaTeX_Listener(PD_Document * pDocument, IE_Exp_LaTeX * pie)
   : m_pDocument(pDocument),
 	m_pie(pie),
-	m_bInSection(false),
 	m_bInBlock(false),
 	m_bInCell(false),
+	m_bInSection(false),
 	m_bInSpan(false),
 	m_bInFootnote(false),
-	m_bFirstSection(true),
 	m_bInSymbol(0),
 	m_bInCourier(0),
-	m_bInSansSerif(0)
+	m_bInSansSerif(0),
+	m_bFirstSection(true)
 {
 	m_pie->write("%% ================================================================================\n");
 	m_pie->write("%% This LaTeX file was created by AbiWord.                                         \n");
@@ -1308,8 +1302,6 @@ bool s_LaTeX_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 
 			switch (pcro->getObjectType())
 			{
-			int i;
-			
 			case PTO_Image:
 				// TODO we *will* create separate image files.
 				// (we will borrow the code from HTML export)
@@ -1373,7 +1365,7 @@ bool s_LaTeX_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 				return true;
 
 			default:
-				UT_ASSERT(0);
+				UT_ASSERT_HARMLESS(0);
 				return true;
 			}
 		}
@@ -1382,7 +1374,7 @@ bool s_LaTeX_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 		return true;
 		
 	default:
-		UT_ASSERT(0);
+		UT_ASSERT_HARMLESS(0);
 		return false;
 	}
 }
