@@ -70,10 +70,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	{
 		m_sniffer = new IE_Imp_MSWrite_Sniffer ();
 	}
-	else
-	{
-		m_sniffer->ref();
-	}
 
 	mi->name = "MSWrite Importer";
 	mi->desc = "Import MSWrite Documents";
@@ -97,10 +93,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	UT_ASSERT (m_sniffer);
 
 	IE_Imp::unregisterImporter (m_sniffer);
-	if (!m_sniffer->unref())
-	{
-		m_sniffer = 0;
-	}
+	delete m_sniffer;
+	m_sniffer = 0;
 
 	return 1;
 }
