@@ -51,10 +51,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	{
 		m_sniffer = new IE_Imp_OPML_Sniffer (PLUGIN_NAME);
 	}
-	else
-	{
-		m_sniffer->ref();
-	}
 
 	UT_ASSERT (m_sniffer);
 
@@ -80,10 +76,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	UT_return_val_if_fail(m_sniffer, 0);
 
 	IE_Imp::unregisterImporter (m_sniffer);
-	if (!m_sniffer->unref())
-	{
-		m_sniffer = 0;
-	}
+	delete m_sniffer;
+	m_sniffer = 0;
 
 	return 1;
 }
