@@ -28,23 +28,28 @@
 #include "ie_imp_Text.h"
 
 #include <gsf/gsf-input-stdio.h>
+#include <gsf/gsf-output-stdio.h>
 
 #include "xap_Module.h"
 
-/* XPDF/Poppler includes */
-#include "GlobalParams.h"
-#include "Object.h"
-#include "Stream.h"
-#include "Array.h"
-#include "Dict.h"
-#include "XRef.h"
-#include "Catalog.h"
-#include "Page.h"
-#include "PDFDoc.h"
-#include "TextOutputDev.h"
-#include "CharTypes.h"
-#include "UnicodeMap.h"
-#include "Error.h"
+static UT_Error temp_name (UT_String& out_filename)
+{
+	char *temporary_file = NULL;
+	GError *err = NULL;
+	gint tmp_fp = g_file_open_tmp ("XXXXXX", &temporary_file, &err);
+	
+	if (err) 
+		{
+			g_warning (err->message);
+			g_error_free (err); err = NULL;
+			return UT_ERROR;
+		}
+
+	out_filename = temporary_file;
+	g_free (temporary_file);
+	close(tmp_fp);
+	return UT_OK;
+}
 
 class ABI_EXPORT IE_Imp_PDF : public IE_Imp
 {
@@ -63,55 +68,59 @@ public:
   {
     UT_Error rval = UT_ERROR;
 
-	Object obj;
-	obj.initNull();
+	UT_String pdf_on_disk, abw_on_disk;
 
-	// todo: if we really cared, we'd subclass poppler's BaseStream class
-	// todo: with a GsfStream implementation. if we really cared...
-	MemStream * mem_stream = new MemStream ((char *)gsf_input_read (input, gsf_input_size (input), NULL),
-											(Guint)0,
-											(Guint)gsf_input_size (input),
-											&obj);
+	// create temporary file names
+	rval = temp_name (pdf_on_disk);
+	if (rval != UT_OK) return rval;
 
-    PDFDoc * doc = new PDFDoc(mem_stream);
+	rval = temp_name (abw_on_disk);
+	if (rval != UT_OK) return rval;
 
-    globalParams = new GlobalParams("");
-    globalParams->setTextEncoding("UTF-8");
-    globalParams->setTextEOL("\n");
-    globalParams->setTextPageBreaks(gFalse);
-    globalParams->setErrQuiet(gTrue);
+	GsfOutput * output = gsf_output_stdio_new (pdf_on_disk.c_str (), NULL);
+	if (output)
+		{
+			// copy input to disk
+			gboolean copy_res = gsf_input_copy (input, output);
 
-    if(doc->isOk()) {
-      char *temporary_file = NULL;
-	  GError *err = NULL;
-	  gint tmp_fp = g_file_open_tmp ("XXXXXX", &temporary_file, &err);
-	  if (err) {
-		g_warning (err->message);
-		g_error_free (err); err = NULL;
-		return UT_ERROR;
-	  }
-	  close(tmp_fp);
+			gsf_output_close (output);
+			g_object_unref (G_OBJECT (output));
 
-      TextOutputDev *textOut = new TextOutputDev(temporary_file, gFalse, gFalse, gFalse);
-      doc->displayPages(textOut, 1, doc->getNumPages(), 72, 72, 0, gTrue, gFalse, gFalse);
-      delete textOut;
+			if (copy_res)
+				{
+					const char * pdftoabw_argv[4];
 
-	  GsfInput * fp;
-	  fp = gsf_input_stdio_new (temporary_file, NULL);
+					pdftoabw_argv[0] = "pdftoabw";
+					pdftoabw_argv[1] = pdf_on_disk.c_str ();
+					pdftoabw_argv[2] = abw_on_disk.c_str ();
+					pdftoabw_argv[3] = NULL;
 
-	  if (fp)
-		  {
-			  IE_Imp_Text txt_imp(getDoc(), "UTF-8");      
-			  rval = txt_imp.importFile(fp);
-			  
-			  g_object_unref (G_OBJECT (fp));
-		  }
+					// run conversion
+					if (g_spawn_sync (NULL,
+									  (gchar **)pdftoabw_argv,
+									  NULL,
+									  (GSpawnFlags)(G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL),
+									  NULL,
+									  NULL,
+									  NULL,
+									  NULL,
+									  NULL,
+									  NULL))
+						{
+							char * uri = UT_go_filename_to_uri (abw_on_disk.c_str ());
+							if (uri)
+								{
+									// import the document
+									rval = IE_Imp::loadFile (getDoc (), uri, IE_Imp::fileTypeForSuffix (".abw"));
+									g_free (uri);
+								}
+						}
+				}			
+		}
 
-      remove(temporary_file);
-	  g_free (temporary_file); temporary_file = NULL;
-    }
-
-    delete globalParams;
+	// remove temporary files
+	remove(pdf_on_disk.c_str ());
+	remove(abw_on_disk.c_str ());
 
     return rval;
   }
@@ -164,15 +173,9 @@ public:
     return UT_CONFIDENCE_ZILCH;
   }
 
-  const char * recognizeContentsType (const char * szBuf,
-				      UT_uint32 iNumbytes)
-  {
-    return "none";
-  }
-
   virtual bool getDlgLabels (const char ** pszDesc,
-			     const char ** pszSuffixList,
-			     IEFileType * ft)
+							 const char ** pszSuffixList,
+							 IEFileType * ft)
   {
     *pszDesc = "PDF (.pdf)";
     *pszSuffixList = "*.pdf";
@@ -200,23 +203,32 @@ static IE_Imp_PDF_Sniffer * m_impSniffer = 0;
 ABI_FAR_CALL
 int abi_plugin_register (XAP_ModuleInfo * mi)
 {
-  if (!m_impSniffer)
-    {
-      m_impSniffer = new IE_Imp_PDF_Sniffer ();
-    }
-  else
-    {
-      m_impSniffer->ref();
-    }
-  
-  mi->name    = "PDF Import Filter";
-  mi->desc    = "Import Adobe PDF Documents";
-  mi->version = ABI_VERSION_STRING;
-  mi->author  = "Dom Lachowicz <cinamod@hotmail.com>";
-  mi->usage   = "No Usage";
-  
-  IE_Imp::registerImporter (m_impSniffer);
-  return 1;
+	gchar * prog_path;
+
+	prog_path = g_find_program_in_path ("pdftoabw");
+	if (prog_path)
+		{
+			// don't register the plugin if it can't find pdftoabw
+			g_free (prog_path);
+
+			if (!m_impSniffer)
+				{
+					m_impSniffer = new IE_Imp_PDF_Sniffer ();
+				}
+			
+			mi->name    = "PDF Import Filter";
+			mi->desc    = "Import Adobe PDF Documents";
+			mi->version = ABI_VERSION_STRING;
+			mi->author  = "Dom Lachowicz <cinamod@hotmail.com>";
+			mi->usage   = "No Usage";
+			
+			IE_Imp::registerImporter (m_impSniffer);
+			return 1;
+		}
+	else
+		{
+			return 1;
+		}
 }
 
 ABI_FAR_CALL
@@ -228,20 +240,19 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
   mi->author = 0;
   mi->usage = 0;
   
-  UT_ASSERT (m_impSniffer);
-
-  IE_Imp::unregisterImporter (m_impSniffer);
-  if (!m_impSniffer->unref())
-    {
-      m_impSniffer = 0;
-    }
+  if (m_impSniffer)
+	  {
+		  IE_Imp::unregisterImporter (m_impSniffer);
+		  delete m_impSniffer;
+		  m_impSniffer = 0;
+	  }
 
   return 1;
 }
 
 ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
-				 UT_uint32 release)
+								 UT_uint32 release)
 {
   return 1;
 }
