@@ -1000,10 +1000,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
     {
     	m_impSniffer = new IE_Imp_StarOffice_Sniffer ();
     }
-    else
-    {
-	m_impSniffer->ref();
-    }
 
     mi->name    = "StarOffice .sdw file importer";
     mi->desc    = "Imports StarWriter binary (OLE) documents";
@@ -1028,10 +1024,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
     UT_ASSERT (m_impSniffer);
 
     IE_Imp::unregisterImporter (m_impSniffer);
-    if(!m_impSniffer->unref())
-    {
+	delete m_impSniffer;
 	m_impSniffer = 0;
-    }
 
     return 1;
 }
