@@ -2,7 +2,7 @@
 
 /* AbiWord
  * Copyright (C) 2001 AbiSource, Inc.
- * Copyright (C) 2002-2004 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002-2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2002-2005 William Lachance (william.lachance@sympatico.ca)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  * 
@@ -55,8 +55,6 @@
 #include "fl_AutoLists.h"
 #include "fl_AutoNum.h"
 
-#include "ap_Strings.h"
-
 #include "ie_imp_WordPerfect.h"
 #include "ie_impexp_WordPerfect.h"
 
@@ -300,10 +298,6 @@ bool IE_Imp_WordPerfect_Sniffer::getDlgLabels  (const char ** pszDesc,
 
 IE_Imp_WordPerfect::IE_Imp_WordPerfect(PD_Document * pDocument)
   : IE_Imp (pDocument),
-	m_bParagraphChanged(false),
-	m_bParagraphInSection(false),
-	m_bInSection(false),
-	m_bSectionChanged(false),
 	m_leftPageMargin(1.0f),
 	m_rightPageMargin(1.0f),
 	m_leftSectionMargin(0.0f),
@@ -315,6 +309,10 @@ IE_Imp_WordPerfect::IE_Imp_WordPerfect(PD_Document * pDocument)
 	m_leftMarginOffset(0.0f),
 	m_rightMarginOffset(0.0f),
 	m_pCurrentListDefinition(NULL),
+	m_bParagraphChanged(false),
+	m_bParagraphInSection(false),
+	m_bInSection(false),
+	m_bSectionChanged(false),
 	m_iCurrentListLevel(0),
 	m_bInCell(false),
 	m_bHdrFtrOpenCount(0)
@@ -328,8 +326,6 @@ IE_Imp_WordPerfect::~IE_Imp_WordPerfect()
 
 UT_Error IE_Imp_WordPerfect::_loadFile(GsfInput * input)
 {
-	GError *err = NULL;
-
 	AbiWordperfectInputStream gsfInput(input);
 	WPDResult error = WPDocument::parse(&gsfInput, static_cast<WPXHLListenerImpl *>(this));
 
