@@ -27,7 +27,7 @@
 #include <stdio.h>
 
 extern "C" {
-#include <eps.h>
+#include <eps/eps.h>
 }
 
 #include "ut_string.h"
@@ -141,7 +141,7 @@ private:
 	UT_Multipart *	m_document;
 	UT_Vector *		m_parts;
 
-	struct eps_t *	m_eps;
+	eps_t *	m_eps;
 };
 
 class MultiReader : public UT_XML::Reader
