@@ -1035,7 +1035,7 @@ void IE_Imp_XSL_FO::createImage(const char *name, const gchar **atts)
 	if (IE_ImpGraphic::loadGraphic (filename.utf8_str(), IEGFT_Unknown, &pfg) != UT_OK)
 		return;
 
-	UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(pfg)->getRaster_PNG();
+	const UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(pfg)->getRaster_PNG();
 	X_CheckError(pBB);
 
 	UT_UTF8String dataid;
